Index: trunk/psLib/src/sysUtils/psErrorCodes.h
===================================================================
--- trunk/psLib/src/sysUtils/psErrorCodes.h	(revision 2129)
+++ trunk/psLib/src/sysUtils/psErrorCodes.h	(revision 2204)
@@ -7,6 +7,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-10-14 21:14:58 $
+ *  @version $Revision: 1.12 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-27 00:57:31 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -15,4 +15,6 @@
 #ifndef PS_ERROR_CODES_H
 #define PS_ERROR_CODES_H
+
+#include "psType.h"
 
 /* N.B., lines between '//~Start' and '//~End' are automatic generated from
@@ -93,12 +95,12 @@
 void psErrorRegister(
     const psErrorDescription* errors,  ///< Array of error codes to register
-    int nerror                         ///< number of errors in input array
+    psS32 nerror                         ///< number of errors in input array
 );
 
 /** Clears error codes registered via psErrorRegister.
  *
  *  @return bool    TRUE if given errorcode was removed, otherwise FALSE.
  */
-bool p_psErrorUnregister(
+psBool p_psErrorUnregister(
     psErrorCode code                   ///< the error code to find and remove
 );
@@ -93,12 +95,12 @@
 /** Clears error codes registered via psErrorRegister.
  *
- *  @return bool    TRUE if given errorcode was removed, otherwise FALSE.
+ *  @return psBool    TRUE if given errorcode was removed, otherwise FALSE.
  */
